<?xml version="1.0" encoding="UTF-8"?>
<gui name="kshisen" version="13"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd">
<MenuBar>
  <Menu name="settings">
    <Action name="sounds"/>
    <Separator/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
  <Action name="game_new"/>
  <Action name="move_undo"/>
  <Action name="game_pause"/>
</ToolBar>
</gui>
